@@ -1,11 +1,13 @@
+# frozen_string_literal: true
+
 require 'spec_helper'
 
 describe 'sysctl' do
   let(:title) { 'vm.swappiness' }
-  let(:params) { {:value => '60'} }
+  let(:params) { { value: '60' } }
 
   describe 'rspec group' do
-    it 'should have a catalogue method' do
+    it 'has a catalogue method' do
       expect(catalogue).to be_a(Puppet::Resource::Catalog)
     end
 
@@ -13,7 +15,7 @@ describe 'sysctl' do
       expect(subject.call).to be_a(Puppet::Resource::Catalog)
     end
 
-    it 'should be included in the coverage filter' do
+    it 'is included in the coverage filter' do
       expect(RSpec::Puppet::Coverage.filters).to include('Sysctl[vm.swappiness]')
     end
   end
