@@ -1,7 +1,9 @@
+# frozen_string_literal: true
+
 require 'spec_helper'
 
 describe 'good_dep_host' do
   let(:facts) { { 'operatingsystem' => 'Debian' } }
 
-  it { should compile.with_all_deps }
+  it { is_expected.to compile.with_all_deps }
 end
